[Lldb-commits] [lldb] r245125 - Disable libstdc++ and libcxx data formatter tests on Windows.

Zachary Turner via lldb-commits lldb-commits at lists.llvm.org
Fri Aug 14 16:28:50 PDT 2015


Author: zturner
Date: Fri Aug 14 18:28:49 2015
New Revision: 245125

URL: http://llvm.org/viewvc/llvm-project?rev=245125&view=rev
Log:
Disable libstdc++ and libcxx data formatter tests on Windows.

Neither of these libraries has been ported to Windows.  Eventually
if they are ever ported we can re-enable these tests.  But more
immediately what we need to do is add new data formatters for
MSVC's STL implementation.  This is tracked in
http://llvm.org/pr24460.

Modified:
    lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libcxx/unordered/TestDataFormatterUnordered.py
    lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libcxx/vbool/TestDataFormatterLibcxxVBool.py
    lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/iterator/TestDataFormatterStdIterator.py
    lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/list/TestDataFormatterStdList.py
    lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/map/TestDataFormatterStdMap.py
    lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/string/TestDataFormatterStdString.py
    lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/vbool/TestDataFormatterStdVBool.py
    lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/vector/TestDataFormatterStdVector.py

Modified: lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libcxx/unordered/TestDataFormatterUnordered.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libcxx/unordered/TestDataFormatterUnordered.py?rev=245125&r1=245124&r2=245125&view=diff
==============================================================================
--- lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libcxx/unordered/TestDataFormatterUnordered.py (original)
+++ lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libcxx/unordered/TestDataFormatterUnordered.py Fri Aug 14 18:28:49 2015
@@ -20,6 +20,7 @@ class LibcxxUnorderedDataFormatterTestCa
         self.data_formatter_commands()
 
     @dwarf_test
+    @skipIfWindows # libc++ not ported to Windows yet
     @skipIfGcc
     def test_with_dwarf_and_run_command(self):
         """Test data formatter commands."""

Modified: lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libcxx/vbool/TestDataFormatterLibcxxVBool.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libcxx/vbool/TestDataFormatterLibcxxVBool.py?rev=245125&r1=245124&r2=245125&view=diff
==============================================================================
--- lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libcxx/vbool/TestDataFormatterLibcxxVBool.py (original)
+++ lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libcxx/vbool/TestDataFormatterLibcxxVBool.py Fri Aug 14 18:28:49 2015
@@ -20,7 +20,7 @@ class LibcxxVBoolDataFormatterTestCase(T
         self.data_formatter_commands()
 
     @skipIfGcc
-    @skipIfWindows # http://llvm.org/pr21800
+    @skipIfWindows # libc++ not ported to Windows.
     @dwarf_test
     def test_with_dwarf_and_run_command(self):
         """Test data formatter commands."""

Modified: lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/iterator/TestDataFormatterStdIterator.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/iterator/TestDataFormatterStdIterator.py?rev=245125&r1=245124&r2=245125&view=diff
==============================================================================
--- lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/iterator/TestDataFormatterStdIterator.py (original)
+++ lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/iterator/TestDataFormatterStdIterator.py Fri Aug 14 18:28:49 2015
@@ -20,6 +20,7 @@ class StdIteratorDataFormatterTestCase(T
         self.data_formatter_commands()
 
     @dwarf_test
+    @skipIfWindows # libstdcpp not ported to Windows
     @expectedFailureFreeBSD("llvm.org/pr20548") # fails to build on lab.llvm.org buildbot
     @expectedFailureIcc # llvm.org/pr15301 LLDB prints incorrect sizes of STL containers
     def test_with_dwarf_and_run_command(self):

Modified: lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/list/TestDataFormatterStdList.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/list/TestDataFormatterStdList.py?rev=245125&r1=245124&r2=245125&view=diff
==============================================================================
--- lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/list/TestDataFormatterStdList.py (original)
+++ lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/list/TestDataFormatterStdList.py Fri Aug 14 18:28:49 2015
@@ -20,6 +20,7 @@ class StdListDataFormatterTestCase(TestB
         self.data_formatter_commands()
 
     @dwarf_test
+    @skipIfWindows # libstdcpp not ported to Windows
     @expectedFailureFreeBSD("llvm.org/pr20548") # fails to build on lab.llvm.org buildbot
     def test_with_dwarf_and_run_command(self):
         """Test data formatter commands."""

Modified: lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/map/TestDataFormatterStdMap.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/map/TestDataFormatterStdMap.py?rev=245125&r1=245124&r2=245125&view=diff
==============================================================================
--- lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/string/TestDataFormatterStdString.py (original)
+++ lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/string/TestDataFormatterStdString.py Fri Aug 14 18:28:49 2015
@@ -21,6 +21,7 @@ class StdStringDataFormatterTestCase(Tes
         self.data_formatter_commands()
 
     @expectedFailureFreeBSD("llvm.org/pr20548") # fails to build on lab.llvm.org buildbot
+    @skipIfWindows # libstdcpp not ported to Windows
     @dwarf_test
     def test_with_dwarf_and_run_command(self):
         """Test data formatter commands."""

Modified: lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/vbool/TestDataFormatterStdVBool.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/vbool/TestDataFormatterStdVBool.py?rev=245125&r1=245124&r2=245125&view=diff
==============================================================================
--- lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/vbool/TestDataFormatterStdVBool.py (original)
+++ lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/vbool/TestDataFormatterStdVBool.py Fri Aug 14 18:28:49 2015
@@ -22,7 +22,7 @@ class StdVBoolDataFormatterTestCase(Test
 
     @expectedFailureFreeBSD("llvm.org/pr20548") # fails to build on lab.llvm.org buildbot
     @dwarf_test
-    @skipIfWindows # http://llvm.org/pr21800
+    @skipIfWindows # libstdcpp not ported to Windows.
     @skipIfDarwin
     def test_with_dwarf_and_run_command(self):
         """Test data formatter commands."""

Modified: lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/vector/TestDataFormatterStdVector.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/vector/TestDataFormatterStdVector.py?rev=245125&r1=245124&r2=245125&view=diff
==============================================================================
--- lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/vector/TestDataFormatterStdVector.py (original)
+++ lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/vector/TestDataFormatterStdVector.py Fri Aug 14 18:28:49 2015
@@ -22,6 +22,7 @@ class StdVectorDataFormatterTestCase(Tes
     @dwarf_test
     @skipIfFreeBSD
     @expectedFailureIcc # llvm.org/pr15301 LLDB prints incorrect sizes of STL containers
+    @skipIfWindows # libstdcpp not ported to Windows
     def test_with_dwarf_and_run_command(self):
         """Test data formatter commands."""
         self.buildDwarf()




More information about the lldb-commits mailing list
--- lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/map/TestDataFormatterStdMap.py (original)
+++ lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/map/TestDataFormatterStdMap.py Fri Aug 14 18:28:49 2015
@@ -19,8 +19,8 @@ class StdMapDataFormatterTestCase(TestBa
         self.buildDsym()
         self.data_formatter_commands()
 
-    @expectedFailureIcc   # llvm.org/pr15301: LLDB prints incorrect size of
-                          # libstdc++ containers
+    @expectedFailureIcc   # llvm.org/pr15301: LLDB prints incorrect size of libstdc++ containers
+    @skipIfWindows # libstdcpp not ported to Windows
     @skipIfFreeBSD
     @dwarf_test
     def test_with_dwarf_and_run_command(self):

Modified: lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/string/TestDataFormatterStdString.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/functionalities/data-formatter/data-formatter-stl/libstdcpp/string/TestDataFormatterStdString.py?rev=245125&r1=245124&r2=245125&view=diff
==============================================================================